# PoPETs publication script
Tool to check and tag submissions for publication.


## Usage

To control an arbitrary execution of code during compilation of latex sources, we sandbox the compilation in a docker container.

 1. Install `docker`: [installation instructions](https://docs.docker.com/engine/installation/) (docker should be able to run without sudo)

 2. Build the `popetstools` docker image: `make build`

 3. Compile latex sources inside the docker image: `make compile ISSUE=<issue> SOURCES=<sources>`

<sources> must be the absolute path to the folder that contains the compressed files of issue <issue> submissions. The filename of the compressed file must follow the pattern: `paper<paper-submission-number>-<issue-year>-<issue-number>-source.zip`.

 Example: `make compile ISSUE=1 SOURCES=/tmp/sources/issue1` (`/tmp/sources/issue1` is the folder that contains the file `paper1-2024-1-source.zip`)

 4. The output files placed under `./pdfs`. There are two files: a YAML files and one PDF file. The YAML files contains the metadata we extract from the metadata.json, while the PDF if the compiled submission.

Note: the page numbers and DOI in the final output are merely placeholders. It will only be finalized when the paper is made available online.



## Constrains for camera ready

We enforce a number of rules on the authors that simplify the logic to be implemented in popetstools.

Authors should:

 - Name their `main` tex file as 'main.tex'.

 - Verify the paper can be compiled with:

	* `pdflatex + bibtex/biber/... + pdflatex + pdflatex`

 - Verify that `metadata.json` is inside the compressed submission. It should be in the same folder as `main.tex`.

 - The references must be introduced in the 'main.tex' (e.g., \bibliography, \printbibliography, \begin{thebibliography}). 

 - The document class and the template lines should be in `main.tex`:

	* \documentclass[sigconf,balance=false]{acmart}

Note: this last requirement is not necessary if the others are met.



## Warnings and Errors

There are several common errors and warnings you may see.

* You may see `WARNING  editor's intro not found!` in the output. Please ignore this warning. It is only relevant to publication chairs.

* `WARNING  no jobs found in /sources!`: Please make sure that (1) the `<issue-number>`, (2) the submission file name (`paperX-XXXX-X-source.zip`), and (3) the path to the folder that contains your submission file are all correct.

* `ERROR    Font <paper-number>-2024-1 in <font-name> is not 'subset'`: There are unsubsetted fonts in your paper. 

* `ERROR    PDF <paper-number>-2024-1 doesn't have font <font-name> embedded`: There are fonts not embedded in the paper. Types of fonts that are allowed: Type 1, TrueType, CID TrueType, Type 1C

* `ERROR    Missing metadata.json! Please make sure that metadata.json is placed inside your submission and is in the same folder as main.tex.`: Please make sure that your metadata.json is included in your submission.

* `ERROR    Malformatted metadata.json! Please check if your metadata.json is formatted correctly.`: Please make sure that your metadata.json is formatted correctly:
	* Common errors: 
		* Trailing comma at the end of author list.
		* `"` or `'` in the abstract are not handled correctly.
		* Abstract with multiple paragraphs. 
